@@ -5,49 +5,44 @@ import django
 from django.core.exceptions import ImproperlyConfigured
 from django.db import models
 
-from .utils import get_content_type, get_content_types, get_queryset
+from .utils import get_queryset
 
 
 class PolymorphicQuerySet(models.query.QuerySet):
-    def select_subclasses(self, *args):
+    def select_subclasses(self, *models):
         self.type_cast = True
-        content_type_field_name = self.model.CONTENT_TYPE_FIELD
-        lookups = set([content_type_field_name])
+        relateds = set([self.model.CONTENT_TYPE_FIELD])
         opts = self.model._meta
         accessors = opts._subclass_accessors
-        if args:
-            subclasses = set()
-            # Collect all subclasses
-            for subclass in args:
-                if not issubclass(subclass, self.model):
+        if models:
+            subclasses = set([])
+            for model in models:
+                if not issubclass(model, self.model):
                     raise TypeError(
-                        "%r is not a subclass of %r" % (subclass, self.model)
+                        "%r is not a subclass of %r" % (model, self.model)
                     )
-                subclasses.update(subclass._meta._subclass_accessors.keys())
+                subclasses.update(model._meta._subclass_accessors.keys())
             # Collect all `select_related` required lookups
             for subclass in subclasses:
                 # Avoid collecting ourself and proxy subclasses
-                subclass_lookup = accessors[subclass][2]
-                if subclass_lookup:
-                    lookups.add(subclass_lookup)
-            # Fetch associated `ContentType` instances for filtering
-            content_types = get_content_types(subclasses)
-            filters = {"%s__in" % content_type_field_name:
-                       tuple(ct.pk for ct in content_types.values())}
-            qs = self.filter(**filters)
+                related = accessors[subclass][2]
+                if related:
+                    relateds.add(related)
+            qs = self.filter(
+                **self.model.content_type_lookup(*tuple(subclasses))
+            )
         else:
-            # Collect all `select_related` required lookups
+            # Collect all `select_related` required relateds
             for accessor in accessors.values():
                 # Avoid collecting ourself and proxy subclasses
+                related = accessor[2]
                 if accessor[2]:
-                    lookups.add(accessor[2])
+                    relateds.add(related)
             qs = self
-        return qs.select_related(*lookups)
+        return qs.select_related(*relateds)
 
     def exclude_subclasses(self):
-        content_type_field_name = self.model.CONTENT_TYPE_FIELD
-        model_content_type = get_content_type(self.model)
-        return self.filter(**{content_type_field_name: model_content_type})
+        return self.filter(**self.model.content_type_lookup())
 
     def _clone(self, *args, **kwargs):
         kwargs.update(type_cast=getattr(self, 'type_cast', False))
@@ -72,13 +67,19 @@ class PolymorphicManager(models.Manager):
         from .models import BasePolymorphicModel
         if not issubclass(model, BasePolymorphicModel):
             raise ImproperlyConfigured(
-                '`PolymorphicManager` can only be used on '
-                '`BasePolymorphicModel` subclasses.'
+                '`%s` can only be used on '
+                '`BasePolymorphicModel` subclasses.' % self.__class__.__name__
             )
         return super(PolymorphicManager, self).contribute_to_class(model, name)
 
     def get_queryset(self):
-        return PolymorphicQuerySet(self.model, using=self._db)
+        model = self.model
+        qs = PolymorphicQuerySet(model, using=self._db)
+        opts = model._meta
+        if opts.proxy:
+            # Select only associated model and it's subclasses
+            qs = qs.filter(**self.model.subclasses_lookup())
+        return qs
 
     if django.VERSION < (1, 8):
         if django.VERSION >= (1, 6):
